%
%
% ----------------- PDF files indexer ------------------------------------------
% If you have a directory/subdirectory filled with PDF files, this matlab script
% will generate a webpage (biblio.html) with a sortable table containing the authors, title words, journal, year, with links to
% your pdf files, and a link to PubMed to related papers. The first row allows you to filter the table according to a keyword (i.e. keep only the rows
%	containing the keyword). Click on the second row to oerder alphabetically.
% The file names of the PDF files is assumed to be of the form:
% author1-author2-author3+article-title-words+Journal+Year.pdf
%(if not so, edit the first part of the matlab code below)
%
% If you improve this code, please email the new code and I will post it on the webpage, with proper acknowledgements.
% Author: Jean-Marc Fellous (fellous@email.arizona.edu)
% 7/2006- ver 1.0. Note the .js files were taken from the web, and edited.



% Change this to the root directory of the pdf files.
rootdir='C:\JM\Reprints';

cd(rootdir)
[s list, m]=fileattrib('*');
N=length(list);

% read all the files, and parse authors, title and journal.
% You might want to modify this if your file names are not in the format above.
% the important part is to generate the cell arrays: names, authors,titles, journs and years
names=cell(1,N);
levels=cell(1,N);depths=[];
authors=cell(1,N);titles=cell(1,N);journs=cell(1,N);years=cell(1,N);
for i=1:N
	item=list(i);	
	if item.directory~=1
		k=findstr(rootdir,item.Name);
		names{i}=item.Name(k+length(rootdir)+1:end);
		levels{i}=findstr(names{i},'\');
		k=length(levels{i});
		depths=[depths k];
		temp=names{i};temp2=levels{i};
		if k>0
			fname=temp(temp2(k)+1:end);
		else
			fname=temp;
		end
		seps=findstr(fname,'+');
		if length(seps)==3
			ext=findstr(fname,'.pdf');
			authors{i}=fname(1:seps(1)-1);
			titles{i}=fname(seps(1)+1:seps(2)-1);
			journs{i}=fname(seps(2)+1:seps(3)-1);
			years{i}=fname(seps(3)+1:ext-1);
		else
			buf=sprintf('*** Warning: %s is ill formed - Ignored',names{i});
			names{i}='';
			disp(buf)
		end
	end
end


% Create the .html document

fidi=fopen('header.txt','r');			% need this as a string point
fido=fopen('biblio.html','w');
str=fgetl(fidi);
while 1					% just copy header.txt
	if ~ischar(str), break, end
	fprintf(fido,'%s\r\n',str);
	str=fgetl(fidi);
end
fclose(fidi);

for i=1:max(depths)					% generate a table column for each subdirectory
	fprintf(fido,'\t<th><B>Dir%d</B></th>\r\n',i);
end
fprintf(fido,'</tr>\r\n');

cellformat=sprintf('<tr>');
Pubmedlink='<a href="http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Search&db=PubMed&term=';

for i=1:N
	if ~isempty(names{i});
		fprintf(fido,'%s\r\n',cellformat);
		fprintf(fido,'\t<td><a href=%s target="_blank"> PDF </a> </td>\r\n',names{i});		% this is the link to your PDF file
		fprintf(fido,'\t<td>%s</td>\r\n',capitalize(strrep(authors{i},'-',' ')));
%		fprintf(fido,'\t<td>%s %s %s ">%s</a></td>\r\n', Pubmedlink, strrep(authors{i},'-',' '),strrep(titles{i},'-',' '),strrep(titles{i},'-',' '));
		fprintf(fido,'\t<td>%s %s " target="_blank">%s </a></td>\r\n', Pubmedlink, strrep(titles{i},'-',' '),strrep(titles{i},'-',' ')); 	% this queries PubMed for related articles (according to title words)
		fprintf(fido,'\t<td>%s</td>\r\n',strrep(journs{i},'-',' '));
		fprintf(fido,'\t<td>%s</td>\r\n',strrep(years{i},'-',' '));
		levs=levels{i};temp=names{i};idx=1;
		if length(levs)>0
			for k=1:length(levs)
				dirs=temp(idx:levs(k)-1);
				fprintf(fido,'\t<td>%s</td>\r\n',strrep(dirs,'-',' '));
				idx=levs(k)+1;
			end
			for k=length(levs)+1:max(depths)
				fprintf(fido,'\t<td>-</td>\r\n');
			end
		else
			for k=1:max(depths)
				fprintf(fido,'\t<td>-</td>\r\n');
			end
		
		end
		fprintf(fido,'</tr>\r\n');
	end
end
fprintf(fido,'</table><script language="javascript" type="text/javascript"> setFilterGrid("Biblio",0);</script></body></html>\r\n');
fclose(fido);
